@@ -11,6 +11,16 @@ class ResponseSchema:
     vault: Optional[str] = None
 
 
+@dataclass
+class LocalizationSchema:
+    week_start: int
+    locale: str
+    currency: Optional[str]
+    decimal_digits: int
+    money_digits: int
+    percent_digits: int
+
+
 @dataclass
 class RequestSchema:
     config: dict[str, Any]
@@ -18,6 +28,8 @@ class RequestSchema:
     date_from: str  # format `DATE_FORMAT`
     date_to: str  # format `DATE_FORMAT`
     secrets: Optional[dict[str, Any]]
+    timezone: str
+    localization: LocalizationSchema
 
 
 @dataclass
